pub fn is_face_center_supported(shape: VoxelShape, direction: Direction) -> boolExpand description
Checks if a shape provides center support on a face.
The center area is a 12x12 pixel region (0.125 to 0.875 on each axis).
pub fn is_face_center_supported(shape: VoxelShape, direction: Direction) -> boolChecks if a shape provides center support on a face.
The center area is a 12x12 pixel region (0.125 to 0.875 on each axis).