is_face_full

Function is_face_full 

pub fn is_face_full(shape: VoxelShape, direction: Direction) -> bool
Checks if a shape fully covers a face (for SupportType::Full).

Returns true if the 2D projection of the shape on the given face completely covers the 1x1 face area.