pub fn is_face_sturdy(
shape: VoxelShape,
direction: Direction,
support_type: SupportType,
) -> boolExpand description
Checks if a shape is sturdy on a face for the given support type.
pub fn is_face_sturdy(
shape: VoxelShape,
direction: Direction,
support_type: SupportType,
) -> boolChecks if a shape is sturdy on a face for the given support type.