pub fn is_shape_full_block(shape: VoxelShape) -> boolExpand description
Checks if a shape is a full block (covers the entire 0-1 cube).
This matches vanilla’s Block.isShapeFullBlock() used by isSolidRender().
pub fn is_shape_full_block(shape: VoxelShape) -> boolChecks if a shape is a full block (covers the entire 0-1 cube).
This matches vanilla’s Block.isShapeFullBlock() used by isSolidRender().