pub struct ShapeId(pub u16);Expand description
An ID referencing a registered VoxelShape in the ShapeRegistry.
Use this to refer to shapes in a compact way. The actual shape data can be retrieved from the ShapeRegistry using this ID.
Tuple Fields
0: u16Implementations